http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/conf/cluster.properties
----------------------------------------------------------------------
diff --git a/vxquery-server/src/main/resources/conf/cluster.properties 
b/vxquery-server/src/main/resources/conf/cluster.properties
new file mode 100644
index 0000000..4614898
--- /dev/null
+++ b/vxquery-server/src/main/resources/conf/cluster.properties
@@ -0,0 +1,54 @@
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+# 
+#      http://www.apache.org/licenses/LICENSE-2.0
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+
+#The tmp directory for VXQuery
+VXTMP_DIR=/tmp/vxquery
+
+#The tmp directory for cc
+CCTMP_DIR=$VXTMP_DIR/cc
+
+#The tmp directory for nc
+NCTMP_DIR=$VXTMP_DIR/nc
+
+#The directory to put cc logs
+CCLOGS_DIR=$VXTMP_DIR/logs
+
+#The directory to put nc logs
+NCLOGS_DIR=$VXTMP_DIR/logs
+
+#The JAVA_HOME
+JAVA_HOME=$JAVA_HOME
+
+#The directory to put cc logs
+CCOPTS=" -cc-root ${CCTMP_DIR} "
+
+#The directory to put nc logs
+NCOPTS=" -iodevices /home/ecarman/disk1/tmp/,/home/ecarman/disk2/tmp/ "
+#NCOPTS=" -iodevices $NCTMP_DIR "
+
+#CC JAVA_OPTS
+CCJAVA_OPTS="-server -Xmx7G 
-Djava.util.logging.config.file=./vxquery-benchmark/src/main/resources/noaa-ghcn-daily/scripts/testing_logging.properties"
+# debug option: CCJAVA_OPTS="-Xdebug 
-Xrunjdwp:transport=dt_socket,address=7001,server=y,suspend=n -Xmx1g 
-Djava.util.logging.config.file=logging.properties"
+# Yourkit option: 
-agentpath:/tools/yjp-10.0.4/bin/linux-x86-64/libyjpagent.so=port=20001"
+# Yourkit mac option: 
-agentpath:/Applications/YourKit_Java_Profiler.app/bin/mac/libyjpagent.jnilib=sampling
+
+#NC JAVA_OPTS
+NCJAVA_OPTS="-server -Xmx7G 
-Djava.util.logging.config.file=./vxquery-benchmark/src/main/resources/noaa-ghcn-daily/scripts/testing_logging.properties"
+# debug option: NCJAVA_OPTS="-Xdebug 
-Xrunjdwp:transport=dt_socket,address=7002,server=y,suspend=n -Xmx1g 
-Djava.util.logging.config.file=logging.properties"
+# Yourkit option: 
-agentpath:/tools/yjp-10.0.4/bin/linux-x86-64/libyjpagent.so=port=20001"
+# Yourkit mac option: 
-agentpath:/Applications/YourKit_Java_Profiler.app/bin/mac/libyjpagent.jnilib=sampling

http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/scripts/startcc.sh
----------------------------------------------------------------------
diff --git a/vxquery-server/src/main/resources/scripts/startnc.sh 
b/vxquery-server/src/main/resources/scripts/startnc.sh
index 260512e..7d944f0 100755
--- a/vxquery-server/src/main/resources/scripts/startnc.sh
+++ b/vxquery-server/src/main/resources/scripts/startnc.sh
@@ -25,6 +25,10 @@ CCHOST=$3
 CCPORT=$4
 J_OPTS=$5
 
+#Import cluster properties
+MYDIR="$(dirname -- $0)"
+. ${MYDIR}/../conf/cluster.properties
+
 # Set JAVA_HOME
 export JAVA_HOME=$JAVA_HOME
 
@@ -35,8 +39,14 @@ then
     export JAVA_OPTS
 fi
 
+# java opts added parameters Server cluster.properties
+if [ ! -z "${NCJAVA_OPTS}" ]
+then
+    JAVA_OPTS="${JAVA_OPTS} ${NCJAVA_OPTS}"
+    export JAVA_OPTS
+fi
+
 VXQUERY_HOME=`pwd`
-NCLOGS_DIR=${VXQUERY_HOME}/logs
 
 # logs dir
 mkdir -p $NCLOGS_DIR
@@ -48,6 +58,13 @@ then
        NC_OPTIONS=" ${NC_OPTIONS} -cc-port ${CCPORT} "
 fi
 
+if [ ! -z "${NCOPTS}" ]
+then
+    NC_OPTIONS=" ${NC_OPTIONS} ${NCOPTS} "
+fi
+
+echo "${JAVA_OPTS}" &> ${NCLOGS_DIR}/nc.log
+
 
 # Launch hyracks nc
 ${VXQUERY_HOME}/vxquery-server/target/appassembler/bin/vxquerync ${NC_OPTIONS} 
&> ${NCLOGS_DIR}/nc_$(date +%Y%m%d%H%M).log &

http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/scripts/stopcc.sh
----------------------------------------------------------------------
diff --git a/vxquery-server/src/main/resources/scripts/stopcc.sh 
b/vxquery-server/src/main/resources/scripts/stopcc.sh
index f2b6883..f7fba5c 100755
--- a/vxquery-server/src/main/resources/scripts/stopcc.sh
+++ b/vxquery-server/src/main/resources/scripts/stopcc.sh
@@ -21,6 +21,10 @@ hostname
 
 USER=$1
 
+#Import cluster properties
+MYDIR="$(dirname -- $0)"
+. ${MYDIR}/../conf/cluster.properties
+
 # Kill process
 PID=`ps -ef|grep ${USER}|grep java|grep 'Dapp.name=vxquerycc'|awk '{print $2}'`
 

http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/scripts/stopcluster.sh
----------------------------------------------------------------------
diff --git a/vxquery-server/src/main/resources/scripts/stopcluster.sh 
b/vxquery-server/src/main/resources/scripts/stopcluster.sh
index 5172a2e..b26f5b2 100755
--- a/vxquery-server/src/main/resources/scripts/stopcluster.sh
+++ b/vxquery-server/src/main/resources/scripts/stopcluster.sh
@@ -21,6 +21,10 @@ CCHOST=$1
 CCPORT=$2
 J_OPTS=$3
 
+#Import cluster properties
+MYDIR="$(dirname -- $0)"
+. ${MYDIR}/../conf/cluster.properties
+
 # Export JAVA_HOME
 export JAVA_HOME=${JAVA_HOME}
 
@@ -31,8 +35,14 @@ then
     export JAVA_OPTS
 fi
 
+# java opts added parameters Server cluster.properties
+if [ ! -z "${CCJAVA_OPTS}" ]
+then
+    JAVA_OPTS="${JAVA_OPTS} ${CCJAVA_OPTS}"
+    export JAVA_OPTS
+fi
+
 VXQUERY_HOME=`pwd`
-CCLOGS_DIR=${VXQUERY_HOME}/logs
 
 # logs dir
 mkdir -p ${CCLOGS_DIR}

http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/scripts/stopnc.sh
----------------------------------------------------------------------
diff --git a/vxquery-server/src/main/resources/scripts/stopnc.sh 
b/vxquery-server/src/main/resources/scripts/stopnc.sh
index 8f29de5..5d00c2f 100755
--- a/vxquery-server/src/main/resources/scripts/stopnc.sh
+++ b/vxquery-server/src/main/resources/scripts/stopnc.sh
@@ -21,6 +21,10 @@ hostname
 
 USER=$1
 
+#Import cluster properties
+MYDIR="$(dirname -- $0)"
+. ${MYDIR}/../conf/cluster.properties
+
 # Kill process
 PID=`ps -ef|grep ${USER}|grep java|grep 'Dapp.name=vxquerync'|awk '{print $2}'`
 

Reply via email to
diff --git a/vxquery-server/src/main/resources/scripts/startcc.sh 
b/vxquery-server/src/main/resources/scripts/startcc.sh
index dd1e5be..44b08eb 100755
--- a/vxquery-server/src/main/resources/scripts/startcc.sh
+++ b/vxquery-server/src/main/resources/scripts/startcc.sh
@@ -23,18 +23,28 @@ CCHOST=$1
 CCPORT=$2
 J_OPTS=$3
 
+#Import cluster properties
+MYDIR="$(dirname -- $0)"
+. ${MYDIR}/../conf/cluster.properties
+
 # Export JAVA_HOME
 export JAVA_HOME=${JAVA_HOME}
 
 # java opts added parameters
 if [ ! -z "${J_OPTS}" ]
 then
     JAVA_OPTS="${JAVA_OPTS} ${J_OPTS}"
     export JAVA_OPTS
 fi
 
+# java opts added parameters Server cluster.properties
+if [ ! -z "${CCJAVA_OPTS}" ]
+then
+    JAVA_OPTS="${JAVA_OPTS} ${CCJAVA_OPTS}"
+    export JAVA_OPTS
+fi
+
 VXQUERY_HOME=`pwd`
-CCLOGS_DIR=${VXQUERY_HOME}/logs
 
 # logs dir
 mkdir -p ${CCLOGS_DIR}
@@ -46,5 +56,12 @@ then
     CC_OPTIONS=" ${CC_OPTIONS} -client-net-port ${CCPORT} "
 fi
 
+if [ ! -z "${CCOPTS}" ]
+then
+    CC_OPTIONS=" ${CC_OPTIONS} ${CCOPTS} "
+fi
+
+echo "${JAVA_OPTS}" &> ${CCLOGS_DIR}/cc.log
+
 # Launch hyracks cc script without toplogy
 ${VXQUERY_HOME}/vxquery-server/target/appassembler/bin/vxquerycc ${CC_OPTIONS} 
&> ${CCLOGS_DIR}/cc_$(date +%Y%m%d%H%M).log &

http://git-wip-us.apache.org/repos/asf/vxquery/blob/b665db73/vxquery-server/src/main/resources/scripts/startnc.sh
----------------------------------------------------------------------
@@ -23,18 +23,28 @@ CCHOST=$1
 export JAVA_HOME=${JAVA_HOME}
 
-# java opts added parameters
+# java opts added parameters in XML Cluster config
 if [ ! -z "${J_OPTS}" ]
 then